==> apache-iotdb-1.2.2-source-release.zip: apache-iotdb-1.2.2/iotdb-core/confignode/src/main/java/org/apache/iotdb/confignode/consensus/request/write/trigger/UpdateTriggerStateInTablePlan.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.confignode.consensus.request.write.trigger;

import org.apache.iotdb.confignode.consensus.request.ConfigPhysicalPlan;
import org.apache.iotdb.confignode.consensus.request.ConfigPhysicalPlanType;
import org.apache.iotdb.confignode.rpc.thrift.TTriggerState;
import org.apache.iotdb.tsfile.utils.ReadWriteIOUtils;

import java.io.DataOutputStream;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.util.Objects;

public class UpdateTriggerStateInTablePlan extends ConfigPhysicalPlan {

  private String triggerName;
  private TTriggerState triggerState;

  public UpdateTriggerStateInTablePlan() {
    super(ConfigPhysicalPlanType.UpdateTriggerStateInTable);
  }

  public UpdateTriggerStateInTablePlan(String triggerName, TTriggerState triggerState) {
    super(ConfigPhysicalPlanType.UpdateTriggerStateInTable);
    this.triggerName = triggerName;
    this.triggerState = triggerState;
  }

  public String getTriggerName() {
    return triggerName;
  }

  public void setTriggerName(String triggerName) {
    this.triggerName = triggerName;
  }

  public TTriggerState getTriggerState() {
    return triggerState;
  }

  public void setTriggerState(TTriggerState triggerState) {
    this.triggerState = triggerState;
  }

  @Override
  protected void serializeImpl(DataOutputStream stream) throws IOException {
    stream.writeShort(getType().getPlanType());

    ReadWriteIOUtils.write(triggerName, stream);
    ReadWriteIOUtils.write(triggerState.getValue(), stream);
  }

  @Override
  protected void deserializeImpl(ByteBuffer buffer) throws IOException {
    triggerName = ReadWriteIOUtils.readString(buffer);
    triggerState = TTriggerState.findByValue(ReadWriteIOUtils.readInt(buffer));
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    if (!super.equals(o)) {
      return false;
    }
    UpdateTriggerStateInTablePlan that = (UpdateTriggerStateInTablePlan) o;
    return Objects.equals(triggerName, that.triggerName) && triggerState == that.triggerState;
  }

  @Override
  public int hashCode() {
    return Objects.hash(super.hashCode(), triggerName, triggerState);
  }
}

==> apache-iotdb-1.3.5-source-release.zip: apache-iotdb-1.3.5/iotdb-core/confignode/src/main/java/org/apache/iotdb/confignode/consensus/request/write/trigger/UpdateTriggerStateInTablePlan.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.confignode.consensus.request.write.trigger;

import org.apache.iotdb.confignode.consensus.request.ConfigPhysicalPlan;
import org.apache.iotdb.confignode.consensus.request.ConfigPhysicalPlanType;
import org.apache.iotdb.confignode.rpc.thrift.TTriggerState;

import org.apache.tsfile.utils.ReadWriteIOUtils;

import java.io.DataOutputStream;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.util.Objects;

public class UpdateTriggerStateInTablePlan extends ConfigPhysicalPlan {

  private String triggerName;
  private TTriggerState triggerState;

  public UpdateTriggerStateInTablePlan() {
    super(ConfigPhysicalPlanType.UpdateTriggerStateInTable);
  }

  public UpdateTriggerStateInTablePlan(String triggerName, TTriggerState triggerState) {
    super(ConfigPhysicalPlanType.UpdateTriggerStateInTable);
    this.triggerName = triggerName;
    this.triggerState = triggerState;
  }

  public String getTriggerName() {
    return triggerName;
  }

  public void setTriggerName(String triggerName) {
    this.triggerName = triggerName;
  }

  public TTriggerState getTriggerState() {
    return triggerState;
  }

  public void setTriggerState(TTriggerState triggerState) {
    this.triggerState = triggerState;
  }

  @Override
  protected void serializeImpl(DataOutputStream stream) throws IOException {
    stream.writeShort(getType().getPlanType());

    ReadWriteIOUtils.write(triggerName, stream);
    ReadWriteIOUtils.write(triggerState.getValue(), stream);
  }

  @Override
  protected void deserializeImpl(ByteBuffer buffer) throws IOException {
    triggerName = ReadWriteIOUtils.readString(buffer);
    triggerState = TTriggerState.findByValue(ReadWriteIOUtils.readInt(buffer));
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    if (!super.equals(o)) {
      return false;
    }
    UpdateTriggerStateInTablePlan that = (UpdateTriggerStateInTablePlan) o;
    return Objects.equals(triggerName, that.triggerName) && triggerState == that.triggerState;
  }

  @Override
  public int hashCode() {
    return Objects.hash(super.hashCode(), triggerName, triggerState);
  }
}
